<p align="center" style="font-size:40px; margin:0px 10px 0px 10px">
    <em>ToyStat</em>
</p>
<p align="center">
    <em>Learning statistics from scratch</em>
</p>

<div align="center">

  <a href="https://github.com/shenxiangzhuang/toystat/actions/workflows/test.yaml" target="_blank">

  <img src="https://github.com/shenxiangzhuang/toystat/actions/workflows/test.yaml/badge.svg" alt="Test">

  </a>


  <a href="https://github.com/shenxiangzhuang/toystat">

  <img alt="Documentation" src="https://github.com/shenxiangzhuang/toystat/actions/workflows/build_docs.yaml/badge.svg"/>

  </a>


  <a href="#">

  <img src="https://img.shields.io/badge/Python-3.8, 3.9, 3.10, 3.11-blue">

  </a>


  <a href="https://pypi.org/project/toystat" target="_blank">

  <img src="https://badge.fury.io/py/toystat.svg" alt="PyPI Package">

  </a>

  <a href="https://codecov.io/gh/shenxiangzhuang/toystat" target="_blank">

  <img src="https://codecov.io/gh/shenxiangzhuang/toystat/branch/master/graph/badge.svg" alt="Coverage">

  </a>


</div>

# About
Learning statistics from scratch!
